# Symd

[![GitHub](https://img.shields.io/badge/github-%23121011.svg?style=for-the-badge&logo=github&logoColor=white)](https://github.com/whitead/symd)

Python package containing some useful functions for working with space groups and a symmetric MD engine. This does not include the MD engine, but instead includes necessary details to set-up symmetry constraints like getting affine matrices and Bravais lattice tensors.

* Read [the tutorial](https://whitead.github.io/symd/Tutorial)
* See [Examples](https://whitead.github.io/symd/toc)
* See [the API](https://whitead.github.io/symd/api)

## Changelog

[See here](https://whitead.github.io/symd/changelog.html)
